@@ -29,12 +29,15 @@
 #include <cassert>
 #include <sstream>
 #include <fstream>
+#include <errno.h>
 #include "ConfigSource.h"
 #include "ConfigArchSource.h"
 #include "FileSystemVisitor.h"
 #include "Directory.h"
 #include "ConfigEntry.h"
 
+#include <algorithm>
+
 /* TODO: generate separate OptionSets for the commands, and check parameter 2 for which option set to process - i.e. use the system. XXX This requires removing the use of getopt from libgetopt++, as we need more flexability that it offers. */
 
 static BoolOption verboseOption(false, 'v', "verbose", "be verbose about operation.");
@@ -76,10 +79,13 @@ getStream(std::vector<std::string> &unnamedparams, string &name)
 
     if (name.find("http://") == 0 || name.find("ftp://") == 0) {
         int handle = mkstemp(tempfile);
+        int sys_result;
         close (handle);
 
         string wgetcmd = string("wget -O ") + tempfile + " " + filename;
-        system(wgetcmd.c_str());
+        if ((sys_result = system(wgetcmd.c_str())) < 0 || WEXITSTATUS(sys_result)) {
+            throw new runtime_error ("wget invocation failed.");
+        }
 
         filename = tempfile;
         filemade=1;
@@ -566,7 +572,17 @@ struct UpdateConfigEntry : public unary_function<void, ConfigEntry &>
         out << "Updating " << anEntry.source()->url(false) << " in ";
         out << relPath + "/" + anEntry.path() << endl;
 
-        anEntry.source()->update (relPath + "/" + anEntry.path());
+	/* FIXME
+	 * A quick hack for Debian bug #288887
+	 * If the path does not exist, perform a simple (non-nested)
+	 * get on it.  Otherwise an update will suffice
+	 */
+        if (!Directory::Exists(anEntry.path())) {
+	  //BuildConfigEntry(out, relPath);
+	  anEntry.source()->get    (relPath + "/" + anEntry.path());
+	} else {
+	  anEntry.source()->update (relPath + "/" + anEntry.path());
+	}
     }
 
     ostream &out;
